@@ -35,6 +35,9 @@ FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'
 # 流程未找到关联的电子文件信息，请检查操作步骤，检查参数，并在修改后重试。
 FAILEDOPERATION_FLOWHASNODOCUMENT = 'FailedOperation.FlowHasNoDocument'
 
+# 当前无可用的许可
+FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
+
 # 签署审核未通过，请先完成审核。
 FAILEDOPERATION_NOSIGNREVIEWPASS = 'FailedOperation.NoSignReviewPass'
 
@@ -176,6 +179,9 @@ INVALIDPARAMETER_DATAEXISTS = 'InvalidParameter.DataExists'
 # 数据不存在。
 INVALIDPARAMETER_DATANOTFOUND = 'InvalidParameter.DataNotFound'
 
+# 部门用户Id不正确
+INVALIDPARAMETER_DEPARTUSERID = 'InvalidParameter.DepartUserId'
+
 # 参数为空，请检查参数修改后重试。
 INVALIDPARAMETER_EMPTYPARAMS = 'InvalidParameter.EmptyParams'
 
@@ -263,6 +269,9 @@ INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 # 不支持的通知类型，请检查并联系客服处理。
 INVALIDPARAMETER_NOTIFYTYPE = 'InvalidParameter.NotifyType'
 
+# 参数Offset不正确
+INVALIDPARAMETER_OFFSET = 'InvalidParameter.Offset'
+
 # 不合法的企业名称，请修改后重试。
 INVALIDPARAMETER_ORGANIZATIONNAME = 'InvalidParameter.OrganizationName'
 
@@ -275,15 +284,18 @@ INVALIDPARAMETER_PERSONAUTOSIGNTAG = 'InvalidParameter.PersonAutoSignTag'
 # 不合法的阅读时长限制，请联系客服了解阅读时长设置规则，修改后重试。
 INVALIDPARAMETER_PREREADTIME = 'InvalidParameter.PreReadTime'
 
-# 签署二维码的有效期不合法，请联系客服了解规则，并修稿后重试。
+# 签署二维码的有效期不合法，请联系客服了解规则，并修改后重试。
 INVALIDPARAMETER_QREFFECTDAY = 'InvalidParameter.QrEffectDay'
 
-# 二维码合同的有效期不合法，请联系客服了解规则，并修稿后重试。
+# 二维码合同的有效期不合法，请联系客服了解规则，并修改后重试。
 INVALIDPARAMETER_QRFLOWEFFECTDAY = 'InvalidParameter.QrFlowEffectDay'
 
 # 不合法的资源类型，请联系客服了解，并在修改后重试。
 INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'
 
+# 角色ID不正确
+INVALIDPARAMETER_ROLEID = 'InvalidParameter.RoleId'
+
 # 不合法的印章id，请检查印章id是够正确，并在修改后重试。
 INVALIDPARAMETER_SEALID = 'InvalidParameter.SealId'
 
@@ -305,6 +317,9 @@ INVALIDPARAMETER_VERIFYCHANNEL = 'InvalidParameter.VerifyChannel'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 无效的手机号
+INVALIDPARAMETERVALUE_INVALIDMOBILE = 'InvalidParameterValue.InvalidMobile'
+
 # 需要屏蔽的告警。
 INVALIDPARAMETERVALUE_MASK = 'InvalidParameterValue.Mask'
 
